Welcome to VFormer's documentation!
======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents

   readme
   installation

.. toctree::
   :maxdepth: 2
   :caption: API Reference
   
   api/attention/index
   api/common/index
   api/decoder/index
   api/encoder/index
   api/functional/index
   api/models/index
   api/utils/index
   api/viz/index

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
